// JavaScript source code
// BMP085 Node-RED node file
module.exports = function (RED) {
    var isensor = require('pk-test');

    // Set the bmp085 debug option from the environment variable
    var debugOption = false;
    if (process.env.hasOwnProperty("RED_DEBUG") && process.env.RED_DEBUG.indexOf("pk-test") >= 0) {
        debugOption = true;
    }

    function isensor_Node(config) {
        RED.nodes.createNode(this, config);

        // node configuration
        this.device = config.device;
        this.timer = config.timer * 1000;
        this.name = config.name;
        this.pressureUnits = config.pressureUnits || "mmHg";
        this.temperatureUnits = config.temperatureUnits || "degC";
        if (this.pressureUnits === "hPa" || this.pressureUnits === "mBar") {
            this.pressureFactor = 1.0;
        } else if (this.pressureUnits === "mmHg") {
            this.pressureFactor = 0.75006;
        } else if (this.pressureUnits === "inHg") {
            this.pressureFactor = 0.0295299;
        } else {
            this.pressureFactor = 1.0;
        }
        this.seaLevel = config.seaLevel || "QFE";
        // Note: height units are only used in the editor: config.height is always in m
        this.height = config.height || 0;
        this.heightUnits = config.heightUnits || "m";
        var node = this;

        var sensor = new pk-test({
            'mode': 1,
            'address': '0x18',
            'device': this.device,
            'debug': debugOption
        });

        var getData = function () {
            // TODO: error handling
            sensor.read(function (data) {
                // data.pressure = (data.pressure/1.3332239).toFixed();
                if (node.seaLevel === "QNH") {
                    data.pressure *= Math.pow(288.15 / (288.15 - 0.0065 * node.height), 5.255876);
                }
                data.pressure *= node.pressureFactor;
                data.pressure = Math.round(data.pressure);
                if (node.temperatureUnits === "degF") {
                    data.temperature = 32 + data.temperature * 1.8;
                }
                var msg = { payload: data };
                node.send(msg);
            });
        }

        getData(); // run on start

        tID = setInterval(getData, this.timer);
        node.on("close", function () {
            clearInterval(tID);
        });
    }

    // Register the node by name.
    RED.nodes.registerType("pk-test", isensor_Node);
}